import pdf2docx
import fitz
import markdown
import pandas as pd
import os

class PDFConverter:
    @staticmethod
    def pdf_to_word(pdf_path, output_path):
        converter = pdf2docx.Converter(pdf_path)
        converter.convert(output_path)
        converter.close()

    @staticmethod
    def pdf_to_images(pdf_path, output_dir):
        doc = fitz.open(pdf_path)
        for page_num in range(len(doc)):
            page = doc.load_page(page_num)
            pix = page.get_pixmap()
            output_path = os.path.join(output_dir, f'page_{page_num + 1}.png')
            pix.save(output_path)

    @staticmethod
    def pdf_to_markdown(pdf_path, output_path):
        # 使用PyMuPDF提取文本并转换为Markdown
        doc = fitz.open(pdf_path)
        markdown_text = ""
        for page in doc:
            markdown_text += page.get_text()
        
        with open(output_path, 'w', encoding='utf-8') as f:
            f.write(markdown_text)

    @staticmethod
    def pdf_to_excel(pdf_path, output_path):
        """
        将PDF转换为Excel
        :param pdf_path: PDF文件路径
        :param output_path: 输出文件路径
        """
        # 使用tabula-py提取表格数据
        import tabula
        df = tabula.read_pdf(pdf_path, pages='all')
        if df:
            df[0].to_excel(output_path, index=False)
        else:
            # 如果没有找到表格，创建一个空的Excel文件
            pd.DataFrame().to_excel(output_path, index=False)